@@ -6,10 +6,11 @@ Created on Tue Apr 28 21:26:06 2020
 @author: oscar
 """
 
+import re as reg
 import traceback
 from copy import deepcopy
-import re as reg
 from sys import exc_info
+
 import pandas as pd
 
 ERR_SYS = "system error: "
@@ -38,7 +39,11 @@ def thread_mention(df_media_tw):
             if df_media_tw.in_reply_to_status_id.iloc[i_t] == None:
                 thread.append(0)
             else:
-                if df_media_tw.in_reply_to_status_id.iloc[i_t] / df_media_tw.tweet_id.iloc[f_t] == 1:
+                if (
+                    float(df_media_tw.in_reply_to_status_id.iloc[i_t])
+                    / float(df_media_tw.tweet_id.iloc[f_t])
+                    == 1
+                ):
                     thread.append(1)
                 else:
                     thread.append(0)
@@ -66,13 +71,12 @@ def create_regex(list_terms):
         DESCRIPTION. lislist without @name
 
     """
-    pattern = r'\b@*' + r'\b|\b@*'.join(list_terms) + r'\b'
+    pattern = r"\b@*" + r"\b|\b@*".join(list_terms) + r"\b"
     pat = reg.compile(pattern)
     return pat
 
 
-class SocialpresTW():
-
+class SocialpresTW:
     def __init__(self, df_tw, df_count, brand, auto_n=True, thread=True):
         """Digital social presence
         This function calculates social presence, comparing it with the
@@ -117,12 +121,12 @@ class SocialpresTW():
             DESCRIPTION. each count number of appearances in Twitter
 
         """
-        col_med = ['created_at', 'description', 'text', 'tweet_id', 'screen_name']
+        col_med = ["created_at", "description", "text", "tweet_id", "screen_name"]
 
         df_tw = self.df_tw
         df_c = self.df_count
         auto_n = self.auto_n
-        df_empty_c = pd.DataFrame(columns=['media', 'mentions'])
+        df_empty_c = pd.DataFrame(columns=["media", "mentions"])
         method_name = "c_pres_tw"
 
         try:
@@ -134,10 +138,14 @@ class SocialpresTW():
             df_tw.text = df_tw.text.apply(lambda x: x.lower())
 
             df_m = deepcopy(df_tw)
-            for idd, row in df_c.set_index('nombre').iterrows():
+            for idd, row in df_c.set_index("nombre").iterrows():
                 if idd:
-                    account_terms_regex = create_regex([t.strip() for t in row.terminos.split(',')])
-                    df_m[f'{idd}'] = df_m['text'].str.contains(account_terms_regex, regex=True)
+                    account_terms_regex = create_regex(
+                        [t.strip() for t in row.terminos.split(",")]
+                    )
+                    df_m[f"{idd}"] = df_m["text"].str.contains(
+                        account_terms_regex, regex=True
+                    )
 
             df_m["auto"] = 0
 
@@ -154,8 +162,8 @@ class SocialpresTW():
                 df_m2 = df_m
 
             df_med_c = df_m2.drop(
-                columns=['created_at', 'description', 'text', 'tweet_id', "auto"]).groupby(
-                    'screen_name')
+                columns=["created_at", "description", "text", "tweet_id", "auto"]
+            ).groupby("screen_name")
             df_med_c = df_med_c.sum().T
 
             df_med_c = pd.DataFrame(df_med_c.T.sum())
@@ -167,7 +175,7 @@ class SocialpresTW():
         except KeyError as e_1:
             print(e_1)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_c = df_empty_c
@@ -175,7 +183,7 @@ class SocialpresTW():
         except AttributeError as e_2:
             print(e_2)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_c = df_empty_c
@@ -183,7 +191,7 @@ class SocialpresTW():
         except Exception as e_3:
             print(e_3)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_c = df_empty_c
@@ -202,7 +210,12 @@ class SocialpresTW():
 
         """
         col_med = [
-            'created_at', 'description', 'text', 'tweet_id', 'in_reply_to_status_id', 'screen_name'
+            "created_at",
+            "description",
+            "text",
+            "tweet_id",
+            "in_reply_to_status_id",
+            "screen_name",
         ]
 
         df_tw = self.df_tw
@@ -210,7 +223,9 @@ class SocialpresTW():
         brand = self.brand
         auto_n = self.auto_n
         thread = self.thread
-        df_empty_id = pd.DataFrame(columns=['created_at', 'text', 'screen_name', 'tweet_id'])
+        df_empty_id = pd.DataFrame(
+            columns=["created_at", "text", "screen_name", "tweet_id"]
+        )
         method_name = "id_pres_tw"
 
         try:
@@ -222,10 +237,14 @@ class SocialpresTW():
             df_tw.text = df_tw.text.apply(lambda x: x.lower())
 
             df_m = deepcopy(df_tw)
-            for idd, row in df_c.set_index('nombre').iterrows():
+            for idd, row in df_c.set_index("nombre").iterrows():
                 if idd:
-                    account_terms_regex = create_regex([t.strip() for t in row.terminos.split(',')])
-                    df_m[f'{idd}'] = df_m['text'].str.contains(account_terms_regex, regex=True)
+                    account_terms_regex = create_regex(
+                        [t.strip() for t in row.terminos.split(",")]
+                    )
+                    df_m[f"{idd}"] = df_m["text"].str.contains(
+                        account_terms_regex, regex=True
+                    )
 
             df_m["auto"] = 0
 
@@ -241,24 +260,31 @@ class SocialpresTW():
             else:
                 df_m2 = df_m
 
-            df_med_id = df_m2[[
-                "created_at", "text", "screen_name", "tweet_id", 'in_reply_to_status_id', brand
-            ]]
+            df_med_id = df_m2[
+                [
+                    "created_at",
+                    "text",
+                    "screen_name",
+                    "tweet_id",
+                    "in_reply_to_status_id",
+                    brand,
+                ]
+            ]
             df_med_id = df_med_id[df_med_id[brand]]
             df_med_id = df_med_id.drop(columns=brand)
             df_med_id = df_med_id.reset_index(drop=True)
 
             if thread:
                 df_med_id_th = thread_mention(df_med_id)
-                df_med_id_th = df_med_id_th.drop(columns='in_reply_to_status_id')
+                df_med_id_th = df_med_id_th.drop(columns="in_reply_to_status_id")
             else:
                 df_med_id_th = deepcopy(df_med_id)
-                df_med_id_th = df_med_id_th.drop(columns='in_reply_to_status_id')
+                df_med_id_th = df_med_id_th.drop(columns="in_reply_to_status_id")
 
         except KeyError as e_1:
             print(e_1)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_id_th = df_empty_id
@@ -266,7 +292,7 @@ class SocialpresTW():
         except AttributeError as e_2:
             print(e_2)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_id_th = df_empty_id
@@ -274,7 +300,7 @@ class SocialpresTW():
         except Exception as e_3:
             print(e_3)
             print(ERR_SYS + str(exc_info()[0]))
-            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            print(f"Class: {self.__str__()}\nMethod: {method_name}")
             traceback.print_exc()
 
             df_med_id_th = df_empty_id
